### Как заводить

накатить все обновления:
* docker compose down 
* make pull
* docker compose up -d

если менял докер-файлы или sh, то образы тоже надо вынести
* docker compose up -d --build

если надо удалить том с зависимостями
* docker compose down -v

### Принципы композа
* Исполняемые скрипты подмонтированы в контейнер: достаточно рестартануть для обновлений.
* Окружение лежит в отдельном томе общее для всех контейнеров и обновляется процессом deps
* Апгрейд постгри тоже прорисходит из deps
* Файловая БД подмонтирована как внешняя директория